==> haskell-yesod-form-1.7.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.7.0
visibility:           public
id:                   yesod-form-1.7.0-ApibjjAYi4DFxg7hcWrdX
key:                  yesod-form-1.7.0-ApibjjAYi4DFxg7hcWrdX
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  dabd196fd86c127c721b1eb076b72e5a
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-form-1.7.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-form-1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-form-1.7.0
hs-libraries:         HSyesod-form-1.7.0-ApibjjAYi4DFxg7hcWrdX
depends:
    aeson-1.5.6.0-CtYtZJraSsHFcsSZaXvlPw
    attoparsec-0.14.1-ANDnhONsuNz9itknOOpUk5 base-4.15.0.0
    blaze-builder-0.4.2.1-1jqIYnOFfUgLYlL3E7ErdB
    blaze-html-0.9.1.2-A7ToP6bilsv6vFr5IXyUxm
    blaze-markup-0.8.2.8-uezXo8Z3y23sFP7d5TsKi
    byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn
    email-validate-2.3.2.13-LKrg0I05HVKHtOIyqT6z5Q
    network-uri-2.6.4.1-LOi07mXRxwc6UBMaIKNcH0
    persistent-2.13.0.2-2poHEE1pQYCIzQN58ebtRo
    resourcet-1.2.4.2-DXMRxmjDYKlCownbJXn41q
    shakespeare-2.0.25-3YqmJRHFNrhEHvJW5myBA text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 wai-3.2.3-GMtJihE60kKAQmQoSnr61V
    xss-sanitize-0.3.6-FvvegGkpSAiBC3JPfDHoey
    yesod-core-1.6.20.1-6dwus8JR4W49IbMakn8V9e
    yesod-persistent-1.6.0.7-AR3GKPAHqLz8lx4ywkvnDg

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.7.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.7.0
visibility:           public
id:                   yesod-form-1.7.0-7mgjDc4LV6nBvw7WuCDFcI
key:                  yesod-form-1.7.0-7mgjDc4LV6nBvw7WuCDFcI
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  105c3a37bd893e3926ad927f8577ab97
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-form-1.7.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-form-1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-form-1.7.0
hs-libraries:         HSyesod-form-1.7.0-7mgjDc4LV6nBvw7WuCDFcI
depends:
    aeson-1.5.6.0-BNspgXAzKp6CkIs2quQxij
    attoparsec-0.14.1-K3GEu9KsQZ4BOtaACmx2c3 base-4.15.0.0
    blaze-builder-0.4.2.1-1jqIYnOFfUgLYlL3E7ErdB
    blaze-html-0.9.1.2-9kaLn1s8Miv60gMIEFPbsP
    blaze-markup-0.8.2.8-CxqYGKF4pIvLGuHMy2X00l
    byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn
    email-validate-2.3.2.13-1uoDmlNM9De2JdMuAzKQCm
    network-uri-2.6.4.1-BLO7J2ZupQZ1TNm4gnLLSm
    persistent-2.13.0.2-BWPWcBPg4jtDZOBrvZXY4I
    resourcet-1.2.4.2-C19MLccVwM3ICk9gxUD8Z6
    shakespeare-2.0.25-CDtGA5lU9s7pzDMhJCvnx text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 wai-3.2.3-6ssOiFNCDUB7FIlU1WaKjP
    xss-sanitize-0.3.6-BMFILOrFCl8ElNdWb1PQdg
    yesod-core-1.6.20.1-6k8sagFlZFaIBrCUOJnTRV
    yesod-persistent-1.6.0.7-CqzLRajMRn2EXflNQZ4Fqi

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
